==> quick-system-info-gui_23.09.01.tar.xz: quick-system-info-gui/translations/quick-system-info-gui_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>MainWindow</name>
    <message>
        <source>MX Welcome</source>
        <translation type="vanished">MX Benvenuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="109"/>
        <source>&amp;Copy for forum</source>
        <translation>&amp;Copia per il forum</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="92"/>
        <source>Save the displayed system information to a text file.</source>
        <translation>Salva le informazioni di sistema mostrate in un file di testo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <location filename="../mainwindow.cpp" line="91"/>
        <source>Save text...</source>
        <translation>Salva testo...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="106"/>
        <source>Copy the displayed system information to the clipboard, encased in [CODE][/CODE] tags ready to use in a forum post.</source>
        <translation>Copia le informazioni di sistema mostrate negli appunti, racchiuse nei tag [CODE][/CODE] pronte per l&apos;uso in un post del forum.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>Save the system information selected from the list to an archive file.</source>
        <translation>Salva le informazioni di sistema selezionate dall&apos;elenco in un file di archivio.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>&amp;Save...</source>
        <translation>&amp;Salva...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Quit application</source>
        <translation> Chiudi applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>About this application</source>
        <translation>Informazioni su questa applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>About...</source>
        <translation>Info...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="176"/>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Quick System Info</source>
        <translation>Veloce info di sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="61"/>
        <source>Loading...</source>
        <translation>Caricamento...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="180"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>About Quick-System-Info-gui</source>
        <translation>Informazioni su Quick-System-Info-gui</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="95"/>
        <source>&amp;Find...</source>
        <translation>&amp;Trova...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="99"/>
        <location filename="../mainwindow.cpp" line="478"/>
        <source>Find &amp;Next</source>
        <translation>Trova &amp;Prossimo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="115"/>
        <source>Select &amp;All</source>
        <translation>Seleziona &amp;All</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="121"/>
        <source>Revert Selection</source>
        <translation>Ripristina selezione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Program for displaying a quick system info report</source>
        <translation>Programma per la visualizzazione di un rapporto veloce delle informazioni di sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>Open folder</source>
        <translation>Apri cartella</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>&amp;Save (×%1)...</source>
        <translation>&amp;Salva (×%1)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="471"/>
        <source>Find</source>
        <translation>Trova</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>&amp;Find what:</source>
        <translation>&amp;Trova quello che:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>Match c&amp;ase</source>
        <translation>Abbina c&amp;aso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="485"/>
        <source>Match &amp;whole word only</source>
        <translation>Abbina &amp;solo parola intera</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>Direction</source>
        <translation>Direzione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="490"/>
        <source>&amp;Up</source>
        <translation>&amp;Su</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>&amp;Down</source>
        <translation>&amp;Giù</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="533"/>
        <source>Cannot find &quot;%1&quot;</source>
        <translation>Impossibile trovare &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">C&amp;hiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>Save System Information</source>
        <translation>Salva le informazioni di sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="273"/>
        <source>System information saved.</source>
        <translation>Informazioni di sistema salvate.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Could not save system information.</source>
        <translation>Impossibile salvare le informazioni di sistema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>history</source>
        <translation>cronologia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>%1 Help</source>
        <translation>%1 Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Quick System Info (gui)</source>
        <translation>Veloci informazioni di sistema (gui)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Copy for forum</source>
        <translation>Copia per il forum</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="86"/>
        <source>Plain text copy</source>
        <translation>Copia in testo normale</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You must run this program as normal user.</source>
        <translation>Devi eseguire questo programma come utente normale.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <source>This tool displays a the quick system info report in a gui.</source>
        <translation>Questo strumento visualizza un veloce rapporto delle informazioni di sistema in una gui.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
</context>
</TS>

==> quick-system-info-gui_24.12.09.tar.xz: quick-system-info-gui/translations/quick-system-info-gui_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MainWindow</name>
    <message>
        <source>MX Welcome</source>
        <translation type="vanished">MX Benvenuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>&amp;Copy for forum</source>
        <translation>&amp;Copia per il forum</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="43"/>
        <source>Save the displayed system information to a text file.</source>
        <translation>Salva le informazioni di sistema mostrate in un file di testo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <location filename="../mainwindow.cpp" line="91"/>
        <source>Save text...</source>
        <translation>Salva testo...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="71"/>
        <source>Copy the displayed system information to the clipboard, encased in [CODE][/CODE] tags ready to use in a forum post.</source>
        <translation>Copia le informazioni di sistema mostrate negli appunti, racchiuse nei tag [CODE][/CODE] pronte per l&apos;uso in un post del forum.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Save the system information selected from the list to an archive file.</source>
        <translation>Salva le informazioni di sistema selezionate dall&apos;elenco in un file di archivio.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="60"/>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>&amp;Save...</source>
        <translation>&amp;Salva...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Quit application</source>
        <translation> Chiudi applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="139"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>About this application</source>
        <translation>Informazioni su questa applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>About...</source>
        <translation>Info...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="187"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="187"/>
        <location filename="../mainwindow.cpp" line="325"/>
        <location filename="../mainwindow.cpp" line="354"/>
        <source>Quick System Info</source>
        <translation>Veloce info di sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="61"/>
        <source>Loading...</source>
        <translation>Caricamento...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="186"/>
        <source>About Quick-System-Info-gui</source>
        <translation>Informazioni su Quick-System-Info-gui</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="95"/>
        <source>&amp;Find...</source>
        <translation>&amp;Trova...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="99"/>
        <location filename="../mainwindow.cpp" line="481"/>
        <source>Find &amp;Next</source>
        <translation>Trova &amp;Prossimo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="115"/>
        <source>Select &amp;All</source>
        <translation>Seleziona &amp;All</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="121"/>
        <source>Revert Selection</source>
        <translation>Ripristina selezione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="188"/>
        <source>Program for displaying a quick system info report</source>
        <translation>Programma per la visualizzazione di un rapporto veloce delle informazioni di sistema</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licenza</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="193"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <source>Open folder</source>
        <translation>Apri cartella</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="440"/>
        <source>&amp;Save (×%1)...</source>
        <translation>&amp;Salva (×%1)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>Find</source>
        <translation>Trova</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="477"/>
        <source>&amp;Find what:</source>
        <translation>&amp;Trova quello che:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>Match c&amp;ase</source>
        <translation>Abbina c&amp;aso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>Match &amp;whole word only</source>
        <translation>Abbina &amp;solo parola intera</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>Direction</source>
        <translation>Direzione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>&amp;Up</source>
        <translation>&amp;Su</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>&amp;Down</source>
        <translation>&amp;Giù</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>Cannot find &quot;%1&quot;</source>
        <translation>Impossibile trovare &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="482"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">C&amp;hiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>Save System Information</source>
        <translation>Salva le informazioni di sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>System information saved.</source>
        <translation>Informazioni di sistema salvate.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Could not save system information.</source>
        <translation>Impossibile salvare le informazioni di sistema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>history</source>
        <translation>cronologia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="354"/>
        <source>%1 Help</source>
        <translation>%1 Aiuto</translation>
    </message>
    <message>
        <source>Quick System Info (gui)</source>
        <translation type="vanished">Veloci informazioni di sistema (gui)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Copy for forum</source>
        <translation>Copia per il forum</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="86"/>
        <source>Plain text copy</source>
        <translation>Copia in testo normale</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You must run this program as normal user.</source>
        <translation>Devi eseguire questo programma come utente normale.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <source>This tool displays a the quick system info report in a gui.</source>
        <translation>Questo strumento visualizza un veloce rapporto delle informazioni di sistema in una gui.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
</context>
</TS>
